@@ -102,9 +102,10 @@ mod tests {
                     access: ().into(),
                     functions,
                 };
-                api.create(EntryWithDefId::new(
+                api.create(CreateInput::new(
                     EntryDefId::CapGrant,
                     Entry::CapGrant(cap_grant_entry),
+                    ChainTopOrdering::default(),
                 ))
                 .unwrap();
 
