@@ -16,8 +16,8 @@ pub(super) use error::*;
 pub use holo_hash::*;
 pub use holochain_state::source_chain::SourceChainError;
 pub use holochain_state::source_chain::SourceChainResult;
-pub use holochain_types::Timestamp;
 pub use holochain_zome_types::HeaderHashed;
+pub use holochain_zome_types::Timestamp;
 
 #[allow(missing_docs)]
 mod error;
