@@ -370,6 +370,33 @@ impl SweetConductor {
             .map(|h| h.0.clone())
             .expect("Tried to use a conductor that is offline")
     }
+
+    /// Force trigger all dht ops that haven't received
+    /// enough validation receipts yet.
+    pub async fn force_all_publish_dht_ops(&self) {
+        use futures::stream::StreamExt;
+        if let Some(handle) = self.handle.as_ref() {
+            let iter = handle
+                .list_cell_ids(None)
+                .await
+                .expect("Failed to list cell ids")
+                .into_iter()
+                .map(|id| async {
+                    let id = id;
+                    let env = self.get_cell_env(&id).await.unwrap();
+                    let trigger = self.get_cell_triggers(&id).await.unwrap();
+                    (env, trigger)
+                });
+            futures::stream::iter(iter)
+                .then(|f| f)
+                .for_each(|(env, mut triggers)| async move {
+                    crate::test_utils::force_publish_dht_ops(&env, &mut triggers.publish_dht_ops)
+                        .await
+                        .unwrap();
+                })
+                .await;
+        }
+    }
 }
 
 /// Get a websocket client on localhost at the specified port
