@@ -20,7 +20,11 @@ fn invalid_cell_zome() -> InlineZome {
         .callback("create", move |api, entry: Post| {
             let entry_def_id: EntryDefId = entry_def.id.clone();
             let entry = Entry::app(entry.try_into().unwrap()).unwrap();
-            let hash = api.create(EntryWithDefId::new(entry_def_id, entry))?;
+            let hash = api.create(CreateInput::new(
+                entry_def_id,
+                entry,
+                ChainTopOrdering::default(),
+            ))?;
             Ok(hash)
         })
         .callback("read", |api, hash: HeaderHash| {
