@@ -183,7 +183,7 @@ pub async fn setup_app(
 ) -> (TestEnvs, RealAppInterfaceApi, ConductorHandle) {
     let envs = test_environments();
     let conductor_handle = ConductorBuilder::with_mock_dna_store(dna_store)
-        .test(&envs)
+        .test(&envs, &[])
         .await
         .unwrap();
 
@@ -194,11 +194,16 @@ pub async fn setup_app(
         .unwrap();
 
     conductor_handle
-        .activate_app("test app".to_string())
+        .clone()
+        .enable_app(&"test app".to_string())
         .await
         .unwrap();
 
-    let errors = conductor_handle.clone().setup_cells().await.unwrap();
+    let errors = conductor_handle
+        .clone()
+        .reconcile_cell_status_with_app_status()
+        .await
+        .unwrap();
 
     assert!(errors.is_empty());
 
